[Zope3-checkins] CVS: Zope3/src/zope/app/interfaces/container - __init__.py:1.8

Guido van Rossum guido@python.org
Wed, 26 Feb 2003 11:12:07 -0500


Update of /cvs-repository/Zope3/src/zope/app/interfaces/container
In directory cvs.zope.org:/tmp/cvs-serv30716/src/zope/app/interfaces/container

Modified Files:
	__init__.py 
Log Message:
Rename manage_afterAdd and manage_beforeDelete to afterAddHook and
beforeDeleteHook.  Patch contributed by Christian Heimes.


=== Zope3/src/zope/app/interfaces/container/__init__.py 1.7 => 1.8 ===
--- Zope3/src/zope/app/interfaces/container/__init__.py:1.7	Tue Feb 11 10:59:51 2003
+++ Zope3/src/zope/app/interfaces/container/__init__.py	Wed Feb 26 11:11:36 2003
@@ -152,11 +152,11 @@
 
         Returns the key used, which might be different than the given key.
 
         If the object has an adpter to IAddNotifiable then the manageAfterAdd
         method on the adpter will be called after the object is added.
 
         An IObjectAddedEvent will be published after the object is added and
         after manageAfterAdd is called. The event object will be the added
         object in the context of the container
 
         An IObjectModifiedEvent will be published after the IObjectAddedEvent
@@ -169,11 +169,11 @@
         Raises a KeyError if the object is not found.
 
         If the object has an adpter to IDeleteNotifiable then the
         manageBeforeDeleteObject method on the adpter will be called before
         the object is removed.
 
         An IObjectRemovedEvent will be published before the object is
         removed and before  manageBeforeDeleteObject is called.
         The event object will be the removed from the context of the container
 
         An IObjectModifiedEvent will be published after the
@@ -187,19 +187,19 @@
 class IAddNotifiable(Interface):
     """Interface for notification of being added."""
 
-    def manage_afterAdd(object, container):
+    def afterAddHook(object, container):
         """Hook method will call after an object is added to container."""
 
 class IDeleteNotifiable(Interface):
     """Interface for notification of being deleted."""
 
-    def manage_beforeDelete(object, container):
+    def beforeDeleteHook(object, container):
         """Hook method will call before object is removed from container."""
 
 class IMoveNotifiable(IDeleteNotifiable, IAddNotifiable):
     """Interface for notification of being deleted, added, or moved."""
 
-    def manage_beforeDelete(object, container, movingTo=None):
+    def beforeDeleteHook(object, container, movingTo=None):
         """Hook method will call before object is removed from container.
 
         If the object is being moved, 'movingTo' will be the unicode path
@@ -208,7 +208,7 @@
         will be None.
         """
 
-    def manage_afterAdd(object, container, movedFrom=None):
+    def afterAddHook(object, container, movedFrom=None):
         """Hook method will call after an object is added to container.
 
         If the object is being moved, 'movedFrom' will be the unicode path
@@ -219,7 +219,7 @@
 
 class ICopyNotifiable(IAddNotifiable):
 
-    def manage_afterAdd(object, container, copiedFrom=None):
+    def afterAddHook(object, container, copiedFrom=None):
         """Hook method. Will be called after an object is added to a
         container.
 
@@ -254,7 +254,7 @@
         given key.
         
         This method must not issue an IObjectAddedEvent, nor must it
         call the manage_afterAdd hook of the object.
         However, it must publish an IObjectModified event for the
         container.
         '''
@@ -267,7 +267,7 @@
 
         movingTo is the unicode path for where the move is to.
         This method should not publish an IObjectRemovedEvent, nor should  
         it call the manage_afterDelete method of the object.
         However, it must publish an IObjectModified event for the container.
         '''
@@ -152,11 +152,11 @@
         Returns the key used, which might be different than the given key.
 
-        If the object has an adpter to IAddNotifiable then the manageAfterAdd
+        If the object has an adpter to IAddNotifiable then the afterAddHook
         method on the adpter will be called after the object is added.
 
@@ -152,11 +152,11 @@
 
         An IObjectAddedEvent will be published after the object is added and
-        after manageAfterAdd is called. The event object will be the added
+        after afterAddHook is called. The event object will be the added
         object in the context of the container
 
@@ -169,11 +169,11 @@
 
         If the object has an adpter to IDeleteNotifiable then the
-        manageBeforeDeleteObject method on the adpter will be called before
+        beforeDeleteHook method on the adpter will be called before
         the object is removed.
 
@@ -169,11 +169,11 @@
 
         An IObjectRemovedEvent will be published before the object is
-        removed and before  manageBeforeDeleteObject is called.
+        removed and before beforeDeleteHook method is called.
         The event object will be the removed from the context of the container
 
@@ -254,7 +254,7 @@
         
         This method must not issue an IObjectAddedEvent, nor must it
-        call the manage_afterAdd hook of the object.
+        call the afterAddHook hook of the object.
         However, it must publish an IObjectModified event for the
         container.
@@ -267,7 +267,7 @@
         movingTo is the unicode path for where the move is to.
         This method should not publish an IObjectRemovedEvent, nor should  
-        it call the manage_afterDelete method of the object.
+        it call the afterDeleteHook method of the object.
         However, it must publish an IObjectModified event for the container.
         '''